@@ -22,7 +22,7 @@ use File::Basename ();
 use File::Path ();
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.27'; # VERSION
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -256,9 +256,15 @@ sub create_cluster_ok
     my $cb;
     my $config = {};
     my $item = $_[$i];
-    if(ref($item) eq '' && Mojo::Loader::data_section($caller, "etc/$item.conf"))
+    unless(ref $item)
     {
-      $item = [ $item, Mojo::Loader::data_section($caller, "etc/$item.conf") ];
+      my $fn = $item;
+      $fn =~ s{::}{-}g;
+      $fn = "etc/$fn.conf";
+      if(Mojo::Loader::data_section($caller, $fn))
+      {
+        $item = [ $item, Mojo::Loader::data_section($caller, $fn) ];
+      }
     }
 
     if(ref $item eq 'ARRAY')
@@ -268,7 +274,11 @@ sub create_cluster_ok
       {
         my $home = File::HomeDir->my_home;
         mkdir "$home/etc" unless -d "$home/etc";
-        open my $fh, '>', "$home/etc/$app_name.conf";
+        open my $fh, '>', do {
+          my $fn = $app_name;
+          $fn =~ s{::}{-}g;
+          $fn = "$home/etc/$fn.conf";
+        };
         print $fh $config;
         close $fh;
         $config = {};
@@ -629,7 +639,7 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
